@@ -23,6 +23,7 @@ from tencentcloud.iotexplorer.v20190423 import models
 class IotexplorerClient(AbstractClient):
     _apiVersion = '2019-04-23'
     _endpoint = 'iotexplorer.tencentcloudapi.com'
+    _service = 'iotexplorer'
 
 
     def CallDeviceActionAsync(self, request):
@@ -137,6 +138,34 @@ class IotexplorerClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateLoRaFrequency(self, request):
+        """创建 LoRa 自定义频点
+
+        :param request: Request instance for CreateLoRaFrequency.
+        :type request: :class:`tencentcloud.iotexplorer.v20190423.models.CreateLoRaFrequencyRequest`
+        :rtype: :class:`tencentcloud.iotexplorer.v20190423.models.CreateLoRaFrequencyResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CreateLoRaFrequency", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateLoRaFrequencyResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateLoRaGateway(self, request):
         """创建新 LoRa 网关设备接口
 
@@ -277,6 +306,34 @@ class IotexplorerClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeleteLoRaFrequency(self, request):
+        """提供删除LoRa自定义频点的能力
+
+        :param request: Request instance for DeleteLoRaFrequency.
+        :type request: :class:`tencentcloud.iotexplorer.v20190423.models.DeleteLoRaFrequencyRequest`
+        :rtype: :class:`tencentcloud.iotexplorer.v20190423.models.DeleteLoRaFrequencyResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DeleteLoRaFrequency", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeleteLoRaFrequencyResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DeleteLoRaGateway(self, request):
         """删除  LoRa 网关的接口
 
@@ -473,6 +530,34 @@ class IotexplorerClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeLoRaFrequency(self, request):
+        """提供查询LoRa自定义频点详情的能力
+
+        :param request: Request instance for DescribeLoRaFrequency.
+        :type request: :class:`tencentcloud.iotexplorer.v20190423.models.DescribeLoRaFrequencyRequest`
+        :rtype: :class:`tencentcloud.iotexplorer.v20190423.models.DescribeLoRaFrequencyResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeLoRaFrequency", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeLoRaFrequencyResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeModelDefinition(self, request):
         """查询产品配置的数据模板信息
 
@@ -809,6 +894,34 @@ class IotexplorerClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ModifyLoRaFrequency(self, request):
+        """修改LoRa自定义频点
+
+        :param request: Request instance for ModifyLoRaFrequency.
+        :type request: :class:`tencentcloud.iotexplorer.v20190423.models.ModifyLoRaFrequencyRequest`
+        :rtype: :class:`tencentcloud.iotexplorer.v20190423.models.ModifyLoRaFrequencyResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ModifyLoRaFrequency", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifyLoRaFrequencyResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ModifyLoRaGateway(self, request):
         """修改 LoRa 网关信息
 
@@ -949,6 +1062,34 @@ class IotexplorerClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def PublishMessage(self, request):
+        """本接口（PublishMessage）用于使用自定义透传协议进行设备远控
+
+        :param request: Request instance for PublishMessage.
+        :type request: :class:`tencentcloud.iotexplorer.v20190423.models.PublishMessageRequest`
+        :rtype: :class:`tencentcloud.iotexplorer.v20190423.models.PublishMessageResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("PublishMessage", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.PublishMessageResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ReleaseStudioProduct(self, request):
         """产品开发完成并测试通过后，通过发布产品将产品设置为发布状态
 
